<?php
/* Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end */

namespace App\Command;

use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;
use Symfony\Component\Console\Style\SymfonyStyle;
use Symfony\Component\DependencyInjection\ContainerInterface;


class ClearOrphanDataCommand extends Command
{
    const DELETE_ATTACHMENT_QUERY = "DELETE FROM PGFILE WHERE UUID NOT IN (SELECT DISTINCT FILE from FILE);";
    const COUNT_ORPHAN_DATA_QUERY = "SELECT COUNT(*) FROM PGFILE WHERE UUID NOT IN (SELECT DISTINCT FILE from FILE);";
    private $container;

    private $entityManager;


    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
        $this->entityManager = $this->container->get('doctrine.orm.entity_manager');
        parent::__construct();
    }

    protected function configure()
    {
        $this
            ->setName('app:clear:orphan:data')
            ->setAliases(['cybersponse:clear:orphan:data'])
            ->setDescription('This command allows you to remove orphan data');
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {
        $io = new SymfonyStyle($input, $output);
        $this->deleteOrphanAttachment($io);
        return Command::SUCCESS;
    }

    private function deleteOrphanAttachment($io): void
    {
        $conn = $this->entityManager->getConnection();
        $orphanDataCount = $conn->fetchAllAssociative(self::COUNT_ORPHAN_DATA_QUERY);
        $orphanDataCount = $orphanDataCount[0]['count'];
        if ($orphanDataCount[0]['count'] == 0) {
            $io->success('No orphan data found for attachments');
            return;
        }
        $io->success($orphanDataCount . ' records will be deleted as part of attachment data cleanup.');

        $delete_stmt = $conn->prepare(self::DELETE_ATTACHMENT_QUERY);
        $delete_stmt->execute();
        $delete_stmt->commit();
    }
}
