<?php

namespace App\Entity\Actors;

use ApiPlatform\Core\Annotation\ApiResource;
use Symfony\Component\Serializer\Annotation\Groups;

/**
 * ApiKey
 *  @ApiResource(
 *     attributes={"validation_groups"={"fsr_primary", "fsr_all"}, "fsr_type"="api_keys", "fsr_module"="appliances", "fsr_singular"="Api Key"},
 *     denormalizationContext={"groups"={"fsr_all", "password"}, "fetch_data"=false, "fsr_type"="api_keys"},
 *     normalizationContext={"circular_reference_limit"=2},
 *     collectionOperations={
 *          "get" = { "path"="api_keys", "security_post_denormalize" = "is_granted('read.appliances', object)" },
 *          "post" = { "path"="api_keys", "security_post_denormalize" = "is_granted('create.appliances', object)" }
 *     },
 *     itemOperations={
 *          "get" = { "path"="api_keys/{uuid}", "security" = "is_granted('read.appliances', object)" },
 *          "put" = { "path"="api_keys/{uuid}", "security" = "is_granted('update.appliances', object)" },
 *          "delete" = { "path"="api_keys/{uuid}", "security" = "is_granted('delete.appliances', object)" }
 *     },
 *     subresourceOperations={
 *     }
 * )
 *
 * @Doctrine\ORM\Mapping\Table(name="actors", indexes={@Doctrine\ORM\Mapping\Index(name="api_keys_id_idx", columns={"id"})})
 * @Doctrine\ORM\Mapping\Entity(repositoryClass="Doctrine\ORM\EntityRepository")
 */
class ApiKey extends \App\Entity\Actors\Actor
{
    use \App\Traits\Trackable;
    use \App\Traits\Indexable;
    use \App\Traits\Taggable;

    /**
     * @var string|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`name`", type="text", length=10485761, nullable=true)
     * @Groups({"fsr_primary", "fsr_all", "name"})
     * @Symfony\Component\Validator\Constraints\NotBlank(groups={"Default", "fsr_primary", "fsr_all"})
     */
    protected $name;


    /**
     * Set name
     *
     * @param string  $name
     *
     * @return ApiKey
     */
    public function setName($name = null)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * Get name
     *
     * @return string 
     */
    public function getName()
    {
        return $this->name;
    }
}