<?php
/* Copyright start
  Copyright (C) 2008 - 2023 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end */

namespace App\Entity\Rules;

use ApiPlatform\Core\Annotation\ApiResource;
use Symfony\Component\Serializer\Annotation\Groups;
use App\Entity\Base\BaseEntity;

/**
 *  @ApiResource(
 *     attributes={"validation_groups"={"fsr_primary", "fsr_all"}, "fsr_type"="preprocessing_rules", "fsr_module"="preprocessing_rules", "fsr_singular"="preprocessing_rule"},
 *     denormalizationContext={"groups"={"fsr_all", "password"}, "fetch_data"=false, "fsr_type"="preprocessing_rules"},
 *     normalizationContext={"ignore_depth"=true},
 *     collectionOperations={
 *          "get" = { "security_post_denormalize" = "is_granted('read.preprocessing_rules', object)" },
 *          "post" = { "security_post_denormalize" = "is_granted('create.preprocessing_rules', object)" }
 *     },
 *     itemOperations={
 *          "get" = { "security" = "is_granted('read.preprocessing_rules', object)" },
 *          "put" = { "security" = "is_granted('update.preprocessing_rules', object)" },
 *          "delete" = { "security" = "is_granted('delete.preprocessing_rules', object)" }
 *     }
 * )
 * @Doctrine\ORM\Mapping\Table(name="preprocessing_rules", indexes={@Doctrine\ORM\Mapping\Index(name="preprocessing_rules_modifydate_idx", columns={"modifydate"}), @Doctrine\ORM\Mapping\Index(name="preprocessing_rules_createdate_idx", columns={"createdate"}), @Doctrine\ORM\Mapping\Index(name="preprocessing_rules_id_idx", columns={"id"})})
 * @Doctrine\ORM\Mapping\Entity(repositoryClass="Doctrine\ORM\EntityRepository")
 * @Doctrine\ORM\Mapping\EntityListeners({"App\EventSubscriber\PreprocessingRuleListener"})
 */
class PreprocessingRule extends BaseEntity
{
    use \App\Traits\Trackable;
    use \App\Traits\Indexable;
    use \App\Traits\Taggable;

    /**
     * @var string|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`applicableon`", type="text", length=10485761, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "applicableOn"})
     */
    protected $applicableOn;

    /**
     * @var bool|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`skipplaybookexecution`", type="boolean", length=10485761, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "skipPlaybookExecution"})
     */
    protected $skipPlaybookExecution;

    /**
     * @var bool|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`isactive`", type="boolean", length=10485761, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "isActive"})
     */
    protected $isActive;

    /**
     * @var int|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`priority`", type="integer", length=10485761, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "priority"})
     * @Symfony\Component\Validator\Constraints\NotBlank(groups={"Default", "fsr_primary", "fsr_all"})
     */
    protected $priority;

    /**
     * @var string|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`entitytype`", type="text", length=300, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "entityType"})
     * @Symfony\Component\Validator\Constraints\NotBlank(groups={"Default", "fsr_primary", "fsr_all"})
     */
    protected $entityType;

   /**
     * @var string|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`description`", type="text", length=10485761, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "description"})
     */
    protected $description;

    /**
     * @var mixed|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`action`", type="jsonb", length=10485761, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "action"})
     */
    protected $action;

    /**
     * @var mixed|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`criteria`", type="jsonb", length=10485761, nullable=true, unique=false)
     * @Groups({"fsr_primary", "fsr_all", "criteria"})
     * @Symfony\Component\Validator\Constraints\NotBlank(groups={"Default", "fsr_primary", "fsr_all"})
     */
    protected $criteria;

    /**
     * @var string|null
     *
     * @Doctrine\ORM\Mapping\Column(name="`name`", type="text", length=10485761, nullable=true, unique=true)
     * @Groups({"fsr_primary", "fsr_all", "name"})
     * @Symfony\Component\Validator\Constraints\NotBlank(groups={"Default", "fsr_primary", "fsr_all"})
     */
    protected $name;

    /**
     * @var \App\Entity\Core\Picklist
     *
     * @Doctrine\ORM\Mapping\ManyToOne(targetEntity="App\Entity\Core\Picklist", cascade={"persist"})
     * @Doctrine\ORM\Mapping\JoinColumns({
     *   @Doctrine\ORM\Mapping\JoinColumn(name="action_type", referencedColumnName="uuid", onDelete="SET NULL")
     * })
     * @Groups({"fsr_primary", "fsr_all", "actionType"})
     * @Symfony\Component\Validator\Constraints\NotBlank(groups={"Default", "fsr_primary", "fsr_all"})
     */
    protected $actionType;

    /**
     * @Doctrine\ORM\Mapping\Column(name="enddate", type="datetime", nullable=true)
     * @Groups({"fsr_primary", "fsr_all", "endDate"})
     */
    protected $endDate;

    /**
     * Set applicableOn
     *
     * @param string  $applicableOn
     *
     * @return PreprocessingRule
     */
    public function setApplicableOn($applicableOn = null)
    {
        $this->applicableOn = $applicableOn;

        return $this;
    }

    /**
     * Get applicableOn
     *
     * @return string
     */
    public function getApplicableOn()
    {
        return $this->applicableOn;
    }

    /**
     * Set skipPlaybookExecution
     *
     * @param bool  $skipPlaybookExecution
     *
     * @return PreprocessingRule
     */
    public function setSkipPlaybookExecution($skipPlaybookExecution = null)
    {
        $this->skipPlaybookExecution = $skipPlaybookExecution;

        return $this;
    }

    /**
     * Get skipPlaybookExecution
     *
     * @return bool
     */
    public function getSkipPlaybookExecution()
    {
        return $this->skipPlaybookExecution;
    }

    /**
     * Set isActive
     *
     * @param bool  $isActive
     *
     * @return PreprocessingRule
     */
    public function setIsActive($isActive = null)
    {
        $this->isActive = $isActive;

        return $this;
    }

    /**
     * Get isActive
     *
     * @return bool
     */
    public function getIsActive()
    {
        return $this->isActive;
    }

    /**
     * Set priority
     *
     * @param int  $priority
     *
     * @return PreprocessingRule
     */
    public function setPriority($priority = null)
    {
        $this->priority = $priority;

        return $this;
    }

    /**
     * Get priority
     *
     * @return int
     */
    public function getPriority()
    {
        return $this->priority;
    }

    /**
     * Set entityType
     *
     * @param string  $entityType
     *
     * @return PreprocessingRule
     */
    public function setEntityType($entityType = null)
    {
        $this->entityType = $entityType;

        return $this;
    }

    /**
     * Get entityType
     *
     * @return string
     */
    public function getEntityType()
    {
        return $this->entityType;
    }

    /**
     * Set description
     *
     * @param string  $description
     *
     * @return PreprocessingRule
     */
    public function setDescription($description = null)
    {
        $this->description = $description;

        return $this;
    }

    /**
     * Get description
     *
     * @return string
     */
    public function getDescription()
    {
        return $this->description;
    }

    /**
     * Set action
     *
     * @param mixed  $action
     *
     * @return PreprocessingRule
     */
    public function setAction($action = null)
    {
        $this->action = $action;

        return $this;
    }

    /**
     * Get action
     *
     * @return mixed
     */
    public function getAction()
    {
        return $this->action;
    }

    /**
     * Set criteria
     *
     * @param mixed  $criteria
     *
     * @return PreprocessingRule
     */
    public function setCriteria($criteria = null)
    {
        $this->criteria = $criteria;

        return $this;
    }

    /**
     * Get criteria
     *
     * @return mixed
     */
    public function getCriteria()
    {
        return $this->criteria;
    }

    /**
     * Set name
     *
     * @param string  $name
     *
     * @return PreprocessingRule
     */
    public function setName($name = null)
    {
        $this->name = $name;

        return $this;
    }

    /**
     * Get name
     *
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * Set actionType
     *
     * @param \App\Entity\Core\Picklist  $actionType
     *
     * @return PreprocessingRule
     */
    public function setActionType(\App\Entity\Core\Picklist $actionType = null)
    {
        $this->actionType = $actionType;

        return $this;
    }

    /**
     * Get actionType
     *
     * @return \App\Entity\Core\Picklist
     */
    public function getActionType()
    {
        return $this->actionType;
    }

    /**
     * @return mixed
     */
    public function getEndDate()
    {
        return $this->endDate;
    }

    /**
     * @param mixed $endDate
     */
    public function setEndDate($endDate): void
    {
        $this->endDate = $endDate;
    }




}