<?php
/* Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end */

namespace App\EventSubscriber;

use App\Entity\Actors\Actor;
use App\Entity\Actors\ApiKey;
use App\Entity\Base\BaseEntity;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\ViewEvent;
use Symfony\Component\Serializer\SerializerInterface;
use ApiPlatform\Symfony\EventListener\EventPriorities;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

class CapturePreAPIKeyBasedCall implements EventSubscriberInterface
{

    private const MAIN_FUNC = 'handlePreAPIKeyBasedCall';

    public function __construct(
        private SerializerInterface $serializer,
        private ParameterBagInterface $parameters,
        private TokenStorageInterface $tokenStorage
    ) {
    }

    public static function getSubscribedEvents(): array
    {
        return [
            KernelEvents::VIEW => [self::MAIN_FUNC, EventPriorities::POST_VALIDATE]
        ];
    }

    public function handlePreAPIKeyBasedCall(ViewEvent $event)
    {
        $request = $event->getRequest();
        $method = $request->getMethod();
        $object = $event->getControllerResult();
        if (!$method || in_array($method, ['GET']) || !$object instanceof BaseEntity) {
            return;
        }
        if (get_class($this->tokenStorage->getToken()->getUser()) == ApiKey::class && $object instanceof Actor) {
            throw new AccessDeniedException();
        }
    }
}