<?php

namespace App\EventSubscriber;

use App\Constants\CacheConstants;
use App\Entity\Rules\PreprocessingRule;
use Psr\Cache\InvalidArgumentException;
use Symfony\Contracts\Cache\TagAwareCacheInterface;

class PreprocessingRuleListener
{
    private $cache;

    public function __construct(
        TagAwareCacheInterface $cache
    ) {
        $this->cache = $cache;
    }

    /**
     * @throws InvalidArgumentException
     */
    private function clearPreprocessingRules(PreprocessingRule $rule): void
    {
        if (!is_null($rule->getEntityType())) {
            $cacheKey =  CacheConstants::PREPROCESSING_RULES . "_" . strtoupper($rule->getEntityType());
            $this->cache->deleteItem($cacheKey);
        }
    }

    /**
     * @throws InvalidArgumentException
     */
    public function postUpdate(PreprocessingRule $rule): void
    {
        $this->clearPreprocessingRules($rule);
    }

    /**
     * @throws InvalidArgumentException
     */
    public function postPersist(PreprocessingRule $rule): void
    {
        $this->clearPreprocessingRules($rule);
    }

    /**
     * @throws InvalidArgumentException
     */
    public function postRemove(PreprocessingRule $rule): void
    {
        $this->clearPreprocessingRules($rule);
    }
}